==> quick-system-info-gui_23.09.01.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Welcome </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copia al fòrum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Desa la informació del sistema mostrada a un fitxer de text.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>Desa el text...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Copia la informació del sistema mostrada  al porta-retalls, delimitada per etiquetes [CODE][/CODE], a punt per usar en missatges al fòrum.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Desa la informació de sistema seleccionada de la llista en un fitxer d&apos;arxiu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>De&amp;sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>About this application</source>
        <translation>Quant aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="176"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Quick System Info</source>
        <translation>Informació ràpida del Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Carregant...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Quant a Informació-Ràpida -del-Sistema-igu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Find &amp;Next</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>Selecciona &amp;Tot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>Revoca la Selecció</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programa per a mostrar un informe ràpid del Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Open folder</source>
        <translation>Carpeta oberta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Save (×%1)...</source>
        <translation>De&amp;sa (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Find what:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Match c&amp;ase</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>Match &amp;whole word only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Direction</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>&amp;Up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>&amp;Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registre de canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Save System Information</source>
        <translation>Desa la informació del Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>System information saved.</source>
        <translation>S&apos;ha desat la informació del Sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Could not save system information.</source>
        <translation>No he pogut desar la informació del Sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>history</source>
        <translation>historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Quick System Info (gui)</source>
        <translation>Informació ràpida del Sistema (igu).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>Còpia per al fòrum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>Copia en text net</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Cal executar aquest programa com a usuari normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Aquesta eina mostra una informació ràpida del Sistema en mode gràfic.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
</context>
</TS>

==> quick-system-info-gui_24.04.01.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Welcome </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copia al fòrum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Desa la informació del sistema mostrada a un fitxer de text.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>Desa el text...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Copia la informació del sistema mostrada  al porta-retalls, delimitada per etiquetes [CODE][/CODE], a punt per usar en missatges al fòrum.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Desa la informació de sistema seleccionada de la llista en un fitxer d&apos;arxiu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>De&amp;sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="139"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>About this application</source>
        <translation>Quant aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <location filename="../mainwindow.cpp" line="325"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>Quick System Info</source>
        <translation>Informació ràpida del Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Carregant...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Quant a Informació-Ràpida -del-Sistema-igu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>Find &amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>Selecciona &amp;Tot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>Revoca la Selecció</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programa per a mostrar un informe ràpid del Sistema</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Llicència</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Open folder</source>
        <translation>Carpeta oberta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>&amp;Save (×%1)...</source>
        <translation>De&amp;sa (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>&amp;Find what:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Match c&amp;ase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Match &amp;whole word only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Direction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>&amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registre de canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Save System Information</source>
        <translation>Desa la informació del Sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>System information saved.</source>
        <translation>S&apos;ha desat la informació del Sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Could not save system information.</source>
        <translation>No he pogut desar la informació del Sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>history</source>
        <translation>historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <source>Quick System Info (gui)</source>
        <translation type="vanished">Informació ràpida del Sistema (igu).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>Còpia per al fòrum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>Copia en text net</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Cal executar aquest programa com a usuari normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Aquesta eina mostra una informació ràpida del Sistema en mode gràfic.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
</context>
</TS>
